@@ -8,11 +8,14 @@
 
 import asyncio
 import inspect
+import os
 import signal
 import sys
+from datetime import datetime
 from functools import partial, wraps
+from shutil import move
 
-from typing import Any, Callable, Union
+from typing import Any, Callable, Optional, Union
 
 import click
 from click.decorators import pass_context
@@ -49,12 +52,12 @@ def cli_coro(
     help="Do NOT detach and run in the background.",
 )
 @click.option(
-    "--log",
+    "--log-file",
     type=str,
-    help="Redirects stdout and stderr to a file (append mode).",
+    help="Redirects stdout and stderr to a file (rotates logs).",
 )
 @pass_context
-def start(ctx, debug, log):
+def start(ctx, debug, log_file):
     """Start the daemon."""
 
     # We want to make sure that the Starting <name> ... OK is still output
@@ -62,11 +65,21 @@ def start(ctx, debug, log):
     # create the log and redirect stdout and stderr there. Then call the
     # original worker.
 
-    if log:  # pragma: no cover
+    log_file = log_file or ctx.parent.command.log_file
+
+    if log_file:  # pragma: no cover
         orig_worker = ctx.parent.command.daemon.worker
 
+        log_file = os.path.realpath(os.path.expanduser(os.path.expandvars(log_file)))
+        if os.path.exists(log_file):
+            date = datetime.now()
+            suffix = date.strftime(".%Y-%m-%d_%H:%M:%S")
+            move(log_file, log_file + suffix)
+
+        os.makedirs(os.path.dirname(log_file), exist_ok=True)
+
         def new_worker():
-            f = open(log, "a")
+            f = open(log_file, "w")
             sys.stdout = f
             sys.stderr = f
             orig_worker()
@@ -114,6 +127,7 @@ class DaemonGroup(click.Group):
         self,
         *args,
         callback: Union[Callable[[Any], Any], None] = None,
+        log_file: Optional[str] = None,
         **kwargs,
     ):
 
@@ -123,7 +137,18 @@ class DaemonGroup(click.Group):
         prog = kwargs.pop("prog")
 
         # Here kwargs are the parameters in the @click.group decorator.
-        pidfile = kwargs.pop("pidfile", f"/var/tmp/{prog}.pid")
+        # pidfile is deprecated in Daemon and instead we should use pid_file, but some
+        # code already use pidfile so let's support both but not at the same time.
+        if "pidfile" in kwargs and "pid_file" in kwargs:
+            raise RuntimeError("pid_file and pidfile are mutually exclusive.")
+
+        base_pidfile = f"/var/tmp/{prog}.pid"
+        if "pid_file" in kwargs:
+            pid_file = kwargs.pop("pid_file", base_pidfile)
+        elif "pidfile" in kwargs:
+            pid_file = kwargs.pop("pidfile", base_pidfile)
+        else:
+            pid_file = base_pidfile
 
         daemon_params = {}
         signature = inspect.signature(Daemon).parameters
@@ -131,7 +156,9 @@ class DaemonGroup(click.Group):
             if param in signature and param != "name":
                 daemon_params.update({param: kwargs.pop(param)})
 
-        self.daemon = Daemon(pidfile=pidfile, **daemon_params)
+        self.log_file = log_file
+
+        self.daemon = Daemon(pid_file=pid_file, **daemon_params)
 
         # Callback is the function that @click.group decorates. What we
         # do is store it because it will become the worker for the daemon,
